.. Copyright 2013-2023 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.bootstrap.ui
-----------------------------

.. automodule:: reahl.web.bootstrap.ui


Widgets for constructing a page
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Slot
""""

.. autoclass:: Slot
   :members:

RunningOnBadge
""""""""""""""

.. autoclass:: RunningOnBadge
   :members:


Very low-level Widgets that correspond to HTML 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^


TextNode
""""""""

.. autoclass:: TextNode
   :members:

Title
"""""

.. autoclass:: Title
   :members:

Link
""""

.. autoclass:: Link
   :members:

Head
""""

.. autoclass:: Head
   :members:

Body
""""

.. autoclass:: Body
   :members:

Span
""""

.. autoclass:: Span
   :members:

LiteralHTML
"""""""""""

.. autoclass:: LiteralHTML
   :members:

More commonly used Widgets that correspond to HTML 
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

A
"

.. autoclass:: A
   :members:

H
"

.. autoclass:: H
   :members:

P
"

.. autoclass:: P
   :members:
  
Div
"""

.. autoclass:: Div
   :members:
  
Nav
"""

.. autoclass:: Nav
   :members:

Article
"""""""

.. autoclass:: Article
   :members:

Header
""""""

.. autoclass:: Header
   :members:

Footer
""""""

.. autoclass:: Footer
   :members:

Li
""

.. autoclass:: Li
   :members:

Ul
""

.. autoclass:: Ul
   :members:

Ol
""

.. autoclass:: Ol
   :members:

Img
"""

.. autoclass:: Img
   :members:

Legend
""""""

.. autoclass:: Legend
   :members:

Alert
"""""

.. autoclass:: Alert
   :members:











